/*###############################################################################
# Copyright (C) MOXA Inc. All rights reserved.
#
# This software is distributed under the terms of the
# MOXA License.  See the file COPYING-MOXA for details.
#
# Purpose : MOXA hardware monitor utility 
# Return : 0 on success; Other wise, modification failed.
# Author : Lock Lin
# Date : 2014-05-31
# Version : 1.0
# Notes :
##############################################################################*/


#include <stdint.h>
#include <linux/input.h>
#include <string.h>
#include <fcntl.h>
#include <unistd.h>
#include <stdio.h>
#include <errno.h>
#include <stdlib.h>
#include <signal.h>

#define BUF_MAX                 256
#define BUF_MIN                 128
#define DISK_NAME       	"/dev/sda1"

#ifdef DEBUG
#define DEBUG_PRINT(fmt, args...)    fprintf(stderr, fmt, ## args)
#else
#define DEBUG_PRINT(fmt, args...)    /* Don't do anything in release builds */
#endif


int main (void)
{
	int index;
	double double_val;
	int int_val;
	int cnt = 0;
	unsigned int uint_val;
	unsigned char data[BUF_MIN] = {0};
	int ret = 0;
	int i = 0;

	memset(data, '\0', sizeof(data));
	index = 0;

	/***********************************************/   
	/*           example: get_cpu_count            */
	/***********************************************/
#if 1
	
	ret = get_cpu_count(&cnt);

	if (ret < 0)
		printf("Failed to obtain cpu count, ret:%d\n", ret);
	else
		printf("Total CPU core count: %d\n", cnt);

#endif
	
	/***********************************************/   
	/*      example: get_average_cpu_usage         */
	/***********************************************/

#if 1
	ret = get_average_cpu_usage(&double_val);

	if (ret < 0)
                printf("Failed to obtain total cpu average cpu, ret:%d\n", ret);
        else
                printf("Total CPU usage: %.2f%%\n", double_val);
#endif

	/***********************************************/   
	/*          example: get_cpu_usage             */
	/***********************************************/

#if 1
	for (index = 0; index < cnt; index++) {
		
		ret = get_cpu_usage (index, &double_val);
		
		if (ret < 0)
                	printf("Failed to obtain pre core usage, ret:%d\n", ret);
        	else
			printf("CPU%d Usage: %.2f%%\n", index, double_val);
	}
#endif

	/***********************************************/   
	/*          example: get_mem_total_size        */
	/***********************************************/

#if 1
	ret = get_mem_total_size(&double_val);
		
	if (ret < 0)
		printf("ret:%d\n", ret);
	else
		printf("Total mem size: %.0lf MB\n", double_val);

#endif

	/***********************************************/   
	/*          example: get_mem_avail_size        */
	/***********************************************/

#if 1
	ret = get_mem_avail_size(&double_val);

	if (ret < 0)
		printf("Failed to obtain the memory avail size, ret:%d\n", ret);
	else
		printf("Total avail size: %.0lf MB\n", double_val);
	
#endif

	/***********************************************/   
	/*          example: get_mem_usage             */
	/***********************************************/

#if 1
	ret = get_mem_usage(&int_val);

	if (ret < 0)
		printf("Failed to obtain the memory usage, ret:%d\n", ret);
	else
		printf("Current mem usage: %d %\n", int_val);
#endif 	

	/***********************************************/   
	/*          example: get_uart_count            */
	/***********************************************/

#if 1
	ret = get_uart_count(&cnt);
	
	if (ret < 0){
		printf("Failed to obtain the UART count, ret:%d\n", ret);
		index = 1;
	}else{
		printf("UART count: %d\n", cnt);
	}

#endif 	

	/***********************************************/   
	/*          example: get_uart_status           */
	/***********************************************/

#if 1
	for(i = 0; i < cnt; i++){

		ret = get_uart_status(i, &int_val);		
	
		if (ret < 0)
			printf("Failed to obtain the UART status, ret:%d\n", ret);
		else
			printf ("UART %d: %d \n", i, int_val);
	
	}

#endif 

	/***********************************************/
	/*           example: get_eth_count            */
	/***********************************************/

#if 1
	ret = get_eth_count(&cnt);
	
	if (ret < 0)
		printf("Failed to obtain the cou count, ret:%d\n", ret);
	else
		printf("Ethernet count:%d\n", cnt);



#endif

	for(i = 0; i < cnt; i++){

	/***********************************************/
	/*            example: get_eth_link            */
	/***********************************************/
		
#if 1
		ret = get_eth_link(i, &int_val);
		
		if (ret < 0)
			printf("Failed to obtain the eth%d link status, ret:%d\n", i, ret);
		else
			printf("eth%d link %d\n", i, int_val);

#endif

	/***********************************************/
	/*           example: get_eth_speed            */
	/***********************************************/

#if 1
		ret = get_eth_speed(i, &int_val);

		if (ret < 0)
			printf("Failed to obtain the eth%d speed status, ret:%d\n", i, ret);
		else
			printf("eth%d speed %d\n", i, int_val);

#endif

	/***********************************************/
	/*          example: get_eth_usage             */
	/***********************************************/

#if 1

		ret = get_eth_usage(i, &int_val);
		
		if (ret < 0)
			printf("Failed to obtain the eth%d usage, ret:%d\n", i, ret);
		else
			printf("eth%d usage %d%\n", i, int_val);
		
#endif
	}

	/***********************************************/
	/*          example: get_disk_usage            */
	/***********************************************/

#if 1
	ret = get_disk_usage(DISK_NAME, &double_val);

	if (ret < 0)
		printf("Failed to obtain the disk usage from disk path, ret:%d\n", ret);
	else
		printf ("Disk usage: %.0lf %\n", double_val);
#endif

	/***********************************************/
	/*          example: get_disk_total_size       */
	/***********************************************/

#if 1

	ret = get_disk_total_size(DISK_NAME, &double_val);
	
	if (ret < 0)
		printf("Failed to obtain the disk total size from disk path, ret:%d\n", ret);
	else
		printf("Total avail size: %.0lf MB\n", double_val);

#endif

	/***********************************************/
	/*        example: get_disk_avail_size         */
	/***********************************************/
#if 1

	ret = get_disk_avail_size(DISK_NAME, &double_val);

	if (ret < 0)
		printf("Failed to obtain the disk avail size from disk path, ret:%d\n", ret);
	else
		printf("free size: %.0lf MB\n", double_val);

#endif

	/***********************************************/
	/*        example: get_disk_avail_size         */
	/***********************************************/
#if 1
	//not all board support
	ret = get_pwr_status(0, &int_val);
	
	if (ret < 0)
		printf("Failed to obtain the power supply0 status, ret:%d\n", ret);
	else
		printf("power 0 status: %d\n", int_val);

#endif
	
#if 1
	ret = get_pwr_status(1, &int_val);

	if (ret < 0)
		printf("Failed to obtain the power supply1 status, ret:%d\n", ret);
	else
		printf("power 1 status: %d\n", int_val);
#endif

	/***********************************************/
	/*              example: set_relay             */
	/***********************************************/

#if 1
	ret = set_relay(0, 1);
	
	if (ret < 0)
		printf("Failed to set relay0 on, ret:%d\n", ret);
	else
		printf("set relay status: on\n");
#endif
//	sleep(5);
	
#if 1
	ret = set_relay(0, 0);

	if (ret < 0)
		printf("Failed to set relay0 off, ret:%d\n", ret);
	else
		printf("set relay status: off\n");
#endif

	/***********************************************/
	/*            example: get_milli_volt          */
	/***********************************************/

#if 1
	/* get vcore */
	ret = get_milli_volt(0, &uint_val);
	
	if (ret < 0)
		printf("Failed to obtain the vcore voltage from BIOS, ret:%d\n", ret);
	else
		printf("vcore: %d mv\n", uint_val);

#endif

#if 1
	/* get vdram */
	ret = get_milli_volt(1, &uint_val);
	
	if (ret < 0)
		printf("Failed to obtain the vdram voltage from BIOS, ret:%d\n", ret);
	else
		printf("vdram: %d mv\n", uint_val);

#endif
	
#if 1
	ret = get_milli_volt(2, &uint_val);
	
	if (ret < 0)
		printf("Failed to obtain the 5 voltage from BIOS, ret:%d\n", ret);
	else
		printf("5V: %d mv\n", uint_val);

#endif


	/***********************************************/
	/*            example: get_temperature         */
	/***********************************************/
#if 1

	/* get cpu temperature */
	ret = get_temperature(0, &uint_val);
	
	if (ret < 0)
		printf("Failed to obtain the CPU temp from BIOS, ret:%d\n", ret);
	else
		printf("CPU temp: %d c\n", uint_val);

	/* get sys temperature */

	ret = get_temperature(1, &uint_val);

	if (ret < 0)
		printf("Failed to obtain the system temp from BIOS, ret:%d\n", ret);
	else
		printf("sys temp: %d c\n", uint_val);
#endif

	/***********************************************/
	/*           example: get_device_name          */
	/***********************************************/

#if 1
	/* get device name */
	ret = get_device_name(data);

	if (ret < 0)
		printf("Failed to obtain the device name from BIOS, ret:%d\n", ret);
	else
		printf("device name = %s\n", data);
#endif

	/***********************************************/
	/*            example: get_bios_ver            */
	/***********************************************/

#if 1
	/* get bios version */
	ret = get_bios_ver(data);

	if (ret < 0)
		printf("Failed to obtain the bsio version from BIOS, ret:%d\n", ret);
	else
		printf("BIOS version = %s\n", data);

#endif


	/***********************************************/
	/*          example: get_serial_num            */
	/***********************************************/

#if 1

	/* get serial number */
	ret = get_ser_num(data);
	
	if (ret < 0)
		printf("Failed to obtain the serial number from BIOS, ret:%d\n", ret);
	else
		printf("serial number = %s\n", data);

#endif


}


